function dMRI_get_micro(par,folder,subid)
% Extracts microstructure from the TBSS white matter skeleton
% input:    par     - Microstructure metric to use: choose 'MD','MO','FA',
%                     'ICVF','ISOVF' or 'OD'
%           folder  - Folder containing all subjects folder. Assumes
%                     following folder structure (e.g. for FA):
%                     [folder filesep subid '/dMRI/TBSS/stats/all_FA_skeletonised.nii.gz']
%           subid   - List of subject identifiers
%
% Author: Jeroen Mollink, University of Oxford (mollink.jeroen@gmail.com)

addpath(sprintf('%s/etc/matlab',getenv('FSLDIR')));
mask = read_avw('~/Biobank/Data/dMRI/dMRI/TBSS_mask.nii.gz');
data = zeros(length(subid),sum(mask(:)>0));

out=sprintf('~/Biobank/Data/dMRI/%s_tbss_skel.mat',par);

for i=1:numel(subid);
    T=read_avw(sprintf('%s/%d/dMRI/TBSS/stats/all_%s_skeletonised.nii.gz',folder,subid(i),par));
    data(i,:)=T(mask(:)>0);
    fprintf('Done with subject(%d) %d of %d\n',subid(i),i,numel(subid));
end
save(out,'data');