function rfMRI_processing(folder)
% Generates network matrices from ICA node timeseries
% input:
%      folder       - Folder containing the node timeseries text-files for 
%                     each subject
%
% Author: Jeroen Mollink, University of Oxford (mollink.jeroen@gmail.com)


% Add FSLNets toolbox 
addpath /vols/Data/km/jmollink/Toolboxes/FSLNets/

% Output folder
d = '~/Biobank/Data/rfMRI/ICA/NetMats';
if ~exist(d,'dir'); mkdir(d); end


%%%% LOAD TIMESERIES %%%%
fprintf(1,'Start start cleaning timeseries\n');
% Load timeseries and store in matrix
ts = nets_load(folder,0.735,1);
save(sprintf('%s/timeseries.mat',d),'ts','-v7.3');



%%%% CLEAN RAW TIMESERIES %%%%
fprintf(1,'Start start cleaning timeseries\n');
% Get good ICA components
ICA_id = load(sprintf('%s/../../rfMRI_IC_cluster_LR_goodcomps.txt',d));
% Get non-used components, i.e., not noise, just unusable
nonuse_id = load(sprintf('%s/../../rfMRI_IC_cluster_LR_nonusedcomps.txt',d));

% cleanup and remove bad nodes' timeseries (whichever is not listed in ts.DD is *BAD*).
ts.DD = ICA_id; % Good comps
ts.UNK = nonuse_id; % Non used comps, remainder is bad (noisy) components

% regress the bad nodes out of the good, and then remove the bad nodes' timeseries (1=aggressive, 0=unaggressive (just delete bad)).
ts=nets_tsclean(ts,1);
ts.DD = 1:ts.Nnodes;
save(sprintf('%s/timeseries_cl_aggr.mat',d),'ts','-v7.3');



%%%% GENERATE NETMATS %%%%%%
fprintf(1,'Start generating network matrices\n');
netmats = nets_netmats(ts,1,'ridgep',1);   % Ridge Regression partial, with rho=regularization parameter
[ZNet,MNet] = nets_groupmean(netmats,0);
ts = rmfield(ts,'ts');
save(sprintf('%s/NetMat_ridge.mat',d),'netmats','ZNet','MNet','ts','-v7.3');
fprintf(1,'Done\n');



%%%% GET HOMOTOPIC CONNECTIVITY %%%%
homoi = zeros(162); homoi(1:81,82:end) = eye(81); homoi=logical(homoi);
homo = netmats(:,homoi(:));
save(sprintf('%s/homotopic_FC.mat',d),'homo');



